class TypedPyDefaults:
    additional_properties_default = True
    compact_serialization_default = False
    automatic_enum_conversion = True
    support_json_schema_v6 = False
    uniqueness_features_enabled = False
    defensive_copy_on_get = True
    allow_none_for_optionals = False
    block_unknown_consts = True
